==> haskell-uri-bytestring-aeson-0.1.0.9-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-H0Ee08chX6ET8nK3bLHr1
key:                  uri-bytestring-aeson-0.1.0.9-H0Ee08chX6ET8nK3bLHr1
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  37c07d3c5cda796466be28297531a9c6
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-H0Ee08chX6ET8nK3bLHr1
depends:
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-7yOU4TXNmuXJmRTYiQN8rN

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-aeson-0.1.0.9-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-I4fZ0tTJz6Z38PIaCdQEfy
key:                  uri-bytestring-aeson-0.1.0.9-I4fZ0tTJz6Z38PIaCdQEfy
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  cc5ad487ebfebd4433860b9cab220971
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-I4fZ0tTJz6Z38PIaCdQEfy
depends:
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-7yOU4TXNmuXJmRTYiQN8rN

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
